@@ -26,6 +26,7 @@ use strict;
 use warnings;
 use Test::Parser;
 use XML::Simple;
+use Chart::Graph::Gnuplot qw(gnuplot);
 
 @Test::Parser::Readprofile::ISA = qw(Test::Parser);
 use base 'Test::Parser';
@@ -36,7 +37,7 @@ use fields qw(
               );
 
 use vars qw( %FIELDS $AUTOLOAD $VERSION );
-our $VERSION = '1.6.1';
+our $VERSION = '1.4';
 
 =head2 new()
 
@@ -114,11 +115,11 @@ __END__
 
 =head1 AUTHOR
 
-Mark Wong <markwkm@gmail.com>
+Mark Wong <markw@osdl.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2008 Mark Wong & Open Source Development Labs, Inc.
+Copyright (C) 2006 Mark Wong & Open Source Development Labs, Inc.
 All Rights Reserved.
 
 This script is free software; you can redistribute it and/or modify it
